@@ -1,33 +1,35 @@
 /*
- *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2015 David Barnes
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 1, or (at your option)
- *  any later version.
+ *  This file is part of pgn-extract: a Portable Game Notation (PGN) extractor.
+ *  Copyright (C) 1994-2017 David J. Barnes
  *
- *  This program is distributed in the hope that it will be useful,
+ *  pgn-extract is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  pgn-extract is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
- *  http://www.cs.kent.ac.uk/people/staff/djb/
+ *  along with pgn-extract. If not, see <http://www.gnu.org/licenses/>.
  *
+ *  David J. Barnes may be contacted as d.j.barnes@kent.ac.uk
+ *  https://www.cs.kent.ac.uk/people/staff/djb/
  */
 
 /* Classifications for the arguments allowed in an argsfile. */
+#ifndef ARGSFILE_H
+#define ARGSFILE_H
+
 typedef enum {
     SEVEN_TAG_ROSTER_ARGUMENT = '7',
     GAMES_PER_FILE_ARGUMENT = '#',
     ALTERNATIVE_HELP_ARGUMENT = '?',
     LONG_FORM_ARGUMENT = '-',
     APPEND_TO_OUTPUT_FILE_ARGUMENT = 'a',
-    BOUNDS_ARGUMENT = 'b',
+    MOVE_BOUNDS_ARGUMENT = 'b',
     CHECK_FILE_ARGUMENT = 'c',
     DUPLICATES_FILE_ARGUMENT = 'd',
     USE_ECO_FILE_ARGUMENT = 'e',
@@ -36,6 +38,7 @@ typedef enum {
     WRITE_TO_LOG_FILE_ARGUMENT = 'l',
     NON_MATCHING_GAMES_ARGUMENT = 'n',
     WRITE_TO_OUTPUT_FILE_ARGUMENT = 'o',
+    PLY_BOUNDS_ARGUMENT = 'p',
     CHECK_ONLY_ARGUMENT = 'r',
     KEEP_SILENT_ARGUMENT = 's',
     TAGS_ARGUMENT = 't',
@@ -48,6 +51,7 @@ typedef enum {
     DONT_KEEP_DUPLICATES_ARGUMENT = 'D',
     ECO_OUTPUT_LEVEL_ARGUMENT = 'E',
     OUTPUT_FEN_STRING_ARGUMENT = 'F',
+    HASHCODE_MATCH_ARGUMENT = 'H',
     APPEND_TO_LOG_FILE_ARGUMENT = 'L',
     MATCH_CHECKMATE_ARGUMENT = 'M',
     DONT_KEEP_NAGS_ARGUMENT = 'N',
@@ -62,6 +66,8 @@ typedef enum {
     NO_ARGUMENT_MATCH = '\0'        /* No argument match. */
 } ArgType;
 
-void read_args_file(const char *infile);
 void process_argument(char arg_letter,const char *associated_value);
 int process_long_form_argument(const char *argument, const char *associated_value);
+
+#endif	// ARGSFILE_H
+
