@@ -1,31 +1,33 @@
 /*
- *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2015 David Barnes
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 1, or (at your option)
- *  any later version.
+ *  This file is part of pgn-extract: a Portable Game Notation (PGN) extractor.
+ *  Copyright (C) 1994-2017 David J. Barnes
  *
- *  This program is distributed in the hope that it will be useful,
+ *  pgn-extract is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  pgn-extract is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
- *  http://www.cs.kent.ac.uk/people/staff/djb/
+ *  along with pgn-extract. If not, see <http://www.gnu.org/licenses/>.
  *
+ *  David J. Barnes may be contacted as d.j.barnes@kent.ac.uk
+ *  https://www.cs.kent.ac.uk/people/staff/djb/
  */
 
-
 /* These colour values are used as modifiers of the Piece values to
  * produce pieces of the appropriate colours.
  * A coloured piece is formed by shifting the piece value and setting the
  * bottom bit to either 0 (BLACK) or 1 (WHITE).
  */
+#ifndef DEFS_H
+#define DEFS_H
+#include <stdint.h>
+
 typedef enum { BLACK, WHITE } Colour;
 typedef enum {
     OFF, EMPTY,
@@ -73,8 +75,12 @@ typedef char Col;
  */
 #define HEDGE 2
 
-/* Define a type for position hashing. */
-typedef unsigned long HashCode;
+/* Define a type for position hashing.
+ * The original type for this is unsigned long.
+ * @@@ At some point, it would be worth moving this to uint64_t to be
+ * consistent with the polyglot/zobrist hashing function.
+ */
+typedef uint64_t HashCode;
 
 typedef struct {
     Piece board[HEDGE+BOARDSIZE+HEDGE][HEDGE+BOARDSIZE+HEDGE];
@@ -82,9 +88,11 @@ typedef struct {
     Colour to_move;
     /* The current move number. */
     unsigned move_number;
-    /* Are the following castling options available? */
-    Boolean WKingCastle, WQueenCastle;
-    Boolean BKingCastle, BQueenCastle;
+    /* Rook starting columns for the 4 castling options.
+     * This accommodates Chess960.
+     */
+    Col WKingCastle, WQueenCastle;
+    Col BKingCastle, BQueenCastle;
     /* Keep track of where the two kings are, to make check-detection
      * simple.
      */
@@ -96,7 +104,16 @@ typedef struct {
     Boolean EnPassant;
     Rank ep_rank;
     Col ep_col;
-    HashCode hash_value;
+    /* NB: @@@
+     * This value is based on a relatively weak hashing approach
+     * that really needs updating to properly use the Zobrist hash.
+     */
+    HashCode weak_hash_value;
+    /* Provision for storing a Zobrist hash value. However,
+     * this is only set if GlobalState.add_hashcode_comments.
+     * At some point, it should supersede the weak_hash_value.
+     */
+    uint64_t zobrist;
     /* The half-move clock since the last pawn move or capture. */
     unsigned halfmove_clock;
 } Board;
@@ -114,7 +131,7 @@ typedef struct move_pair {
     
 /* Conversion macros. */
 #define PIECE_SHIFT 3
-#define MAKE_COLOURED_PIECE(colour,piece) (((piece) << PIECE_SHIFT) | (colour))
+#define MAKE_COLOURED_PIECE(colour,piece) ((Piece) (((piece) << PIECE_SHIFT) | (colour)))
 #define W(piece) MAKE_COLOURED_PIECE(WHITE,piece)
 #define B(piece) MAKE_COLOURED_PIECE(BLACK,piece)
 /* Conversion macro, from one colour to another. */
@@ -127,3 +144,6 @@ typedef struct move_pair {
  */
 #define NULL_MOVE_STRING ("--")
 
+
+#endif	// DEFS_H
+
