@@ -1,28 +1,30 @@
 /*
- *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2015 David Barnes
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 1, or (at your option)
- *  any later version.
+ *  This file is part of pgn-extract: a Portable Game Notation (PGN) extractor.
+ *  Copyright (C) 1994-2017 David J. Barnes
  *
- *  This program is distributed in the hope that it will be useful,
+ *  pgn-extract is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  pgn-extract is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
- *  http://www.cs.kent.ac.uk/people/staff/djb/
+ *  along with pgn-extract. If not, see <http://www.gnu.org/licenses/>.
  *
+ *  David J. Barnes may be contacted as d.j.barnes@kent.ac.uk
+ *  https://www.cs.kent.ac.uk/people/staff/djb/
  */
 
         /* Define values for the amount of space to initially malloc
          * and incrementally realloc in a list.
          */
+#ifndef LISTS_H
+#define LISTS_H
+
 #define INIT_LIST_SPACE 10
 #define MORE_LIST_SPACE 5
 
@@ -41,6 +43,10 @@ typedef enum {
 
 void extract_tag_argument(const char *argstr);
 void add_tag_to_list(int tag,const char *tagstr,TagOperator operator);
-Boolean CheckTagDetailsNotECO(char *Details[],int num_details);
-Boolean CheckECOTag(char *Details[]);
+Boolean check_tag_details_not_ECO(char *Details[],int num_details);
+Boolean check_ECO_tag(char *Details[]);
 void init_tag_lists(void);
+Boolean check_setup_tag(char *Details[]);
+
+#endif	// LISTS_H
+
