@@ -1,24 +1,24 @@
 /*
- *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2015 David Barnes
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 1, or (at your option)
- *  any later version.
+ *  This file is part of pgn-extract: a Portable Game Notation (PGN) extractor.
+ *  Copyright (C) 1994-2017 David J. Barnes
  *
- *  This program is distributed in the hope that it will be useful,
+ *  pgn-extract is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  pgn-extract is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
- *  http://www.cs.kent.ac.uk/people/staff/djb/
+ *  along with pgn-extract. If not, see <http://www.gnu.org/licenses/>.
  *
+ *  David J. Barnes may be contacted as d.j.barnes@kent.ac.uk
+ *  https://www.cs.kent.ac.uk/people/staff/djb/
  */
+
         /* Define indices for the set of pre-defined tags.
          * Higher values are created dynamically as new
          * tags are recognised in the source files.
@@ -29,6 +29,9 @@
      * EVENT_DATE_TAG should be in this order because the strings are
      * "Event" and "EventDate".
      */
+#ifndef TAGLIST_H
+#define TAGLIST_H
+
 typedef enum {
     ANNOTATOR_TAG,
     BLACK_TAG,
@@ -78,6 +81,7 @@ typedef enum {
     TIME_CONTROL_TAG,
     UTC_DATE_TAG,
     UTC_TIME_TAG,
+    VARIANT_TAG,
     VARIATION_TAG,
     WHITE_TAG,
     WHITE_ELO_TAG,
@@ -90,3 +94,6 @@ typedef enum {
      */
     ORIGINAL_NUMBER_OF_TAGS
 } TagName;
+
+#endif	// TAGLIST_H
+
